Changed names of functions in utility.c and all affected files, to make
compliant with the style guide. Everybody rebuild your tags file!
diff --git a/procps/kill.c b/procps/kill.c
index dd5ca49..caaa52a 100644
--- a/procps/kill.c
+++ b/procps/kill.c
@@ -204,10 +204,10 @@
 			int pid;
 
 			if (!isdigit(**argv))
-				fatalError( "Bad PID: %s\n", strerror(errno));
+				error_msg_and_die( "Bad PID: %s\n", strerror(errno));
 			pid = strtol(*argv, NULL, 0);
 			if (kill(pid, sig) != 0) 
-				fatalError( "Could not kill pid '%d': %s\n", pid, strerror(errno));
+				error_msg_and_die( "Could not kill pid '%d': %s\n", pid, strerror(errno));
 			argv++;
 		}
 	} 
@@ -219,20 +219,20 @@
 		while (--argc >= 0) {
 			pid_t* pidList;
 
-			pidList = findPidByName( *argv);
+			pidList = find_pid_by_name( *argv);
 			if (!pidList) {
 				all_found = FALSE;
-				errorMsg( "%s: no process killed\n", *argv);
+				error_msg( "%s: no process killed\n", *argv);
 			}
 
 			for(; pidList && *pidList!=0; pidList++) {
 				if (*pidList==myPid)
 					continue;
 				if (kill(*pidList, sig) != 0) 
-					fatalError( "Could not kill pid '%d': %s\n", *pidList, strerror(errno));
+					error_msg_and_die( "Could not kill pid '%d': %s\n", *pidList, strerror(errno));
 			}
 			/* Note that we don't bother to free the memory
 			 * allocated in findPidByName().  It will be freed
 			 * upon exit, so we can save a byte or two */
 			argv++;
 		}
@@ -245,5 +245,5 @@
 
 
   end:
-	fatalError( "bad signal name: %s\n", *argv);
+	error_msg_and_die( "bad signal name: %s\n", *argv);
 }
@@ -219,20 +219,20 @@
 			}
 			/* Note that we don't bother to free the memory
-			 * allocated in findPidByName().  It will be freed
+			 * allocated in find_pid_by_name().  It will be freed
 			 * upon exit, so we can save a byte or two */
 			argv++;